@@ -21,7 +21,8 @@ import os
 import os.path
 
 PACKAGE    = "sabayon"
-VERSION    = "2.11.90"
+VERSION    = "2.12.1"
+LOCALEDIR = "/gnome/head/INSTALL/share/locale"
 DATADIR    = "/gnome/head/INSTALL/share"
 SYSCONFDIR = "/gnome/head/INSTALL/etc"
 LIBEXECDIR = "/gnome/head/INSTALL/libexec"
@@ -45,7 +46,7 @@ XNEST_USR1_TIMEOUT = 10
 # as. The account should be created as part of the packages
 # post installation process
 #
-PROTOTYPE_USER = "sabayon"
+PROTOTYPE_USER = "sabayon-admin"
 
 DEFAULT_PATH  = "/usr/local/bin:/usr/bin:/bin:/usr/X11R6/bin"
 DEFAULT_SHELL = "/bin/bash"
@@ -82,6 +83,7 @@ PASSTHROUGH_ENVIRONMENT = [
 #
 FILES_TO_IGNORE = [
     ".ICEauthority*",
+    ".esd_auth",
     ".fonts.cache-1*",
     ".gconf.path.defaults",
     ".gconf.path.defaults.new",
@@ -102,6 +104,7 @@ DIRECTORIES_TO_IGNORE = [
     ".gconf",
     ".gconf.xml.defaults",
     ".gconf.xml.mandatory",
+    ".gconf.xml.mandatory-alt",
     ".gconfd",
     ".gstreamer-0.8",
     ".metacity/sessions",
