@@ -21,6 +21,7 @@
 import os
 import os.path
 import sys
+import pygtk; pygtk.require('2.0');
 import gobject
 from config import *
 import storage
@@ -134,6 +135,14 @@ class ProfileChange (gobject.GObject):
         """Return a short description of the configuration change."""
         raise Exception ("Not implemented")
 
+    def get_ignore_default (self):
+        """Returns the default value for the ignore item for this change."""
+        return False;
+        
+    def get_mandatory (self):
+        """Returns the mandatory value of the change, or None to use the default"""
+        return None
+
 gobject.type_register (ProfileChange)
 
 class SourceDelegate:
@@ -157,6 +166,13 @@ class SourceDelegate:
         """Returns the configuration delegate's name."""
         return self.name
 
+    def get_path_description (self, path):
+        """Returns a human readable description for @path.
+        @path must have been previously added by the delegate to the
+        #ProfileStorage.
+        """
+        return path
+    
     def handle_change (self, change):
         """Inspect a ProfileChange. Return #True if the change should
         not be passed on any further (i.e. #True == 'handled') and
@@ -184,7 +200,11 @@ class SourceDelegate:
         """Save all committed changes to disk."""
         raise Exception ("Not implemented")
 
-    def apply (self):
+    def set_enforce_mandatory (self, enforce):
+        """Temporary make mandatory setting non-mandatory."""
+        raise Exception ("Not implemented")
+
+    def apply (self, is_sabayon_session):
         """Apply profile to the current user's environment."""
         raise Exception ("Not implemented")
     
@@ -262,7 +282,11 @@ class ProfileSource (gobject.GObject):
         """Save all committed changes to disk."""
         raise Exception ("Not implemented")
 
-    def apply (self):
+    def set_enforce_mandatory (self, enforce):
+        """Temporary make mandatory setting non-mandatory."""
+        raise Exception ("Not implemented")
+    
+    def apply (self, is_sabayon_session):
         """Apply profile to the current user's environment."""
         raise Exception ("Not implemented")
 
@@ -324,9 +348,12 @@ class UserProfile (gobject.GObject):
         """Start monitoring for configuration changes."""
         dprint ("Starting monitoring")
         for s in self.sources:
+            # Start source monitor before delegates so we
+            # can e.g. set up gconf in the gconf source and
+            # use it in the gconf delegate
+            s.start_monitoring ()
             for delegate in s.delegates:
                 delegate.start_monitoring ()
-            s.start_monitoring ()
 
     def stop_monitoring (self):
         """Stop monitoring for configuration changes."""
@@ -345,13 +372,21 @@ class UserProfile (gobject.GObject):
             s.sync_changes ()
         self.storage.save ()
 
-    def apply (self):
+    def set_enforce_mandatory (self, enforce):
+        """Temporary make mandatory setting non-mandatory."""
+        dprint ("Changing mandatory enforcement in user's environment")
+        for s in self.sources:
+            s.set_enforce_mandatory (enforce)
+            for delegate in s.delegates:
+                delegate.set_enforce_mandatory (enforce)
+    
+    def apply (self, is_sabayon_session):
         """Apply profile to the current user's environment."""
         dprint ("Applying profile to user's environment")
         for s in self.sources:
-            s.apply ()
+            s.apply (is_sabayon_session)
             for delegate in s.delegates:
-                delegate.apply ()
+                delegate.apply (is_sabayon_session)
 
 gobject.type_register (UserProfile)
 
